========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/manila.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

======
MANILA
======

You have come across an OpenStack shared file system service.  It has
identified itself as "Manila."  It was abstracted from the Cinder
project.

* Wiki: https://wiki.openstack.org/wiki/Manila
* Developer docs: https://docs.openstack.org/manila/latest/

Getting Started
---------------

If you'd like to run from the master branch, you can clone the git repo:

    git clone https://git.openstack.org/openstack/manila.git

For developer information please see
`HACKING.rst <https://git.openstack.org/cgit/openstack/manila/tree/HACKING.rst>`_

You can raise bugs here https://bugs.launchpad.net/manila

Python client
-------------

https://git.openstack.org/cgit/openstack/python-manilaclient.git

* Release notes for the project can be found at:

https://docs.openstack.org/releasenotes/manila/

